# Release Notes 
## Run Details
- Workflow: Python package CI/CD 
- Head Branch: bugfix/docs_update 
- Head SHA: 1dbf15907f422594580d4828b90f142d5acfee32 

## Pull Requests
**41** Dont update docs on main
### Commits
  - **1dbf15907f422594580d4828b90f142d5acfee32** Update python-package-cicd.yml
### Comments
 - ## Unit Test Results
1 files  ±0  1 suites  ±0   0s [:stopwatch:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;duration of all tests&quot;) ±0s
1 tests ±0  1 [:heavy_check_mark:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;passed tests&quot;) ±0  0 [:zzz:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;skipped / disabled tests&quot;) ±0  0 [:x:](https://github.com/EnricoMi/publish-unit-test-result-action/blob/v1.20/README.md#the-symbols &quot;failed tests&quot;) ±0 

Results for commit 1dbf1590. ± Comparison against base commit c4788b8d.

:recycle: This comment has been updated with latest results.

### linkedIssues
    
